<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="en_US">
<context>
    <name>AboutDialog</name>
    <message>
        <location filename="../AboutDialog.qml" line="44"/>
        <source>cuteTube-QML - 0.9.4</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../AboutDialog.qml" line="56"/>
        <source>A feature-rich YouTube client enabling browsing, playback and download of videos, plus account management. &lt;br&gt;&lt;br&gt; &amp;copy; Stuart Howarth 2011</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>AccountDetailsDialog</name>
    <message>
        <location filename="../AccountDetailsDialog.qml" line="10"/>
        <location filename="../AccountDetailsDialog.qml" line="26"/>
        <source>New Account</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../AccountDetailsDialog.qml" line="15"/>
        <source>Edit Account</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../AccountDetailsDialog.qml" line="46"/>
        <source>Database error. Unable to save account</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../AccountDetailsDialog.qml" line="82"/>
        <source>Username</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../AccountDetailsDialog.qml" line="94"/>
        <source>Password</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../AccountDetailsDialog.qml" line="107"/>
        <source>Default?</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>AccountsDialog</name>
    <message>
        <location filename="../AccountsDialog.qml" line="35"/>
        <source>Database error. Unable to delete account</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../AccountsDialog.qml" line="79"/>
        <source>YouTube Accounts</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>AddCommentDialog</name>
    <message>
        <location filename="../AddCommentDialog.qml" line="6"/>
        <source>Add Comment</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../AddCommentDialog.qml" line="15"/>
        <source>Share Via </source>
        <translation></translation>
    </message>
    <message>
        <location filename="../AddCommentDialog.qml" line="60"/>
        <source>Title</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../AddCommentDialog.qml" line="74"/>
        <source>Description</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../AddCommentDialog.qml" line="111"/>
        <source>Message</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>AddToPlaylistDialog</name>
    <message>
        <location filename="../AddToPlaylistDialog.qml" line="31"/>
        <source>Add To Playlist</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>ArchiveListView</name>
    <message>
        <location filename="../ArchiveListView.qml" line="93"/>
        <source>Deleted from archive</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../ArchiveListView.qml" line="96"/>
        <location filename="../ArchiveListView.qml" line="116"/>
        <source>Unable to delete from archive</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>BusyDialog</name>
    <message>
        <location filename="../BusyDialog.qml" line="45"/>
        <source>Loading...</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>ChangeUserDialog</name>
    <message>
        <location filename="../ChangeUserDialog.qml" line="50"/>
        <source>Change Current User</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>CommentsDelegate</name>
    <message>
        <location filename="../CommentsDelegate.qml" line="19"/>
        <location filename="../CommentsDelegate.qml" line="21"/>
        <source>By </source>
        <translation></translation>
    </message>
    <message>
        <location filename="../CommentsDelegate.qml" line="20"/>
        <location filename="../CommentsDelegate.qml" line="22"/>
        <source> on </source>
        <translation></translation>
    </message>
</context>
<context>
    <name>ConfirmDeleteDialog</name>
    <message>
        <location filename="../ConfirmDeleteDialog.qml" line="30"/>
        <source>Confirm Delete</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ConfirmDeleteDialog.qml" line="42"/>
        <source>Please choose from where you wish to delete the selected videos</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ConfirmDeleteDialog.qml" line="55"/>
        <source>Archive</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ConfirmDeleteDialog.qml" line="65"/>
        <source>Device</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ConfirmExitDialog</name>
    <message>
        <location filename="../ConfirmExitDialog.qml" line="47"/>
        <source>Hold it!</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../ConfirmExitDialog.qml" line="58"/>
        <source>cuteTube is currently downloading. Do you really want to exit?</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../ConfirmExitDialog.qml" line="71"/>
        <source>Yes</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../ConfirmExitDialog.qml" line="81"/>
        <source>No</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>Controller</name>
    <message>
        <location filename="../../../controller.cpp" line="253"/>
        <source>Video deleted from device</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../../controller.cpp" line="256"/>
        <source>Unable to delete video</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../../controller.cpp" line="260"/>
        <source>Video not found</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../../controller.cpp" line="315"/>
        <source>Copied to clipboard</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>FileChooserDialog</name>
    <message>
        <location filename="../FileChooserDialog.qml" line="29"/>
        <source>Choose Video File</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>HomeView</name>
    <message>
        <location filename="../HomeView.qml" line="115"/>
        <source>My Channel</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../HomeView.qml" line="185"/>
        <source>Archive</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>InboxDelegate</name>
    <message>
        <location filename="../InboxDelegate.qml" line="44"/>
        <location filename="../InboxDelegate.qml" line="46"/>
        <source>From </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../InboxDelegate.qml" line="45"/>
        <location filename="../InboxDelegate.qml" line="47"/>
        <location filename="../InboxDelegate.qml" line="95"/>
        <source> on </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../InboxDelegate.qml" line="95"/>
        <source>By </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../InboxDelegate.qml" line="145"/>
        <source>Views</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>InboxDialog</name>
    <message>
        <location filename="../InboxDialog.qml" line="57"/>
        <source>Inbox</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../InboxDialog.qml" line="69"/>
        <source>No messages found</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>MenuBar</name>
    <message>
        <location filename="../MenuBar.qml" line="150"/>
        <source>Sort</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>MyAccountView</name>
    <message>
        <location filename="../MyAccountView.qml" line="91"/>
        <source>My Uploads</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../MyAccountView.qml" line="97"/>
        <source>Uploads</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../MyAccountView.qml" line="115"/>
        <source>My Favourites</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../MyAccountView.qml" line="121"/>
        <source>Favourites</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../MyAccountView.qml" line="145"/>
        <source>Playlists</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../MyAccountView.qml" line="169"/>
        <source>Subscriptions</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../MyAccountView.qml" line="184"/>
        <source>Signed in as:</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>NewPlaylistDialog</name>
    <message>
        <location filename="../NewPlaylistDialog.qml" line="34"/>
        <source>New Playlist</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../NewPlaylistDialog.qml" line="46"/>
        <source>Title</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../NewPlaylistDialog.qml" line="59"/>
        <source>Description (optional)</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../NewPlaylistDialog.qml" line="71"/>
        <source>Private?</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>NoAccountDialog</name>
    <message>
        <location filename="../NoAccountDialog.qml" line="60"/>
        <source>Hi there!</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../NoAccountDialog.qml" line="71"/>
        <source>My name&apos;s Cutey. My buddy Clippy tells me it&apos;s the first time you&apos;ve used cuteTube. Would you like to add a YouTube account?</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../NoAccountDialog.qml" line="84"/>
        <source>Yes</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../NoAccountDialog.qml" line="98"/>
        <source>Go Away</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>NotificationArea</name>
    <message>
        <location filename="../NotificationArea.qml" line="55"/>
        <source>No active downloads</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../NotificationArea.qml" line="151"/>
        <source>Downloads</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>OAuthDialog</name>
    <message>
        <location filename="../OAuthDialog.qml" line="8"/>
        <source>Authorisation For </source>
        <translation></translation>
    </message>
    <message>
        <location filename="../OAuthDialog.qml" line="27"/>
        <source>Error obtaining facebook authorisation</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../OAuthDialog.qml" line="117"/>
        <source>Enter pin code</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>PlaylistDelegate</name>
    <message>
        <location filename="../PlaylistDelegate.qml" line="30"/>
        <source> videos</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>PlaylistDialog</name>
    <message>
        <location filename="../PlaylistDialog.qml" line="80"/>
        <source>Playlist Info</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../PlaylistDialog.qml" line="125"/>
        <source>Title</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../PlaylistDialog.qml" line="131"/>
        <source>Videos</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../PlaylistDialog.qml" line="151"/>
        <source>Created</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../PlaylistDialog.qml" line="157"/>
        <source>Updated</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../PlaylistDialog.qml" line="185"/>
        <source>Description</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../PlaylistDialog.qml" line="203"/>
        <source>No description</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../PlaylistDialog.qml" line="218"/>
        <source>Play</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../PlaylistDialog.qml" line="241"/>
        <source>Download</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>PlaylistVideosView</name>
    <message>
        <location filename="../PlaylistVideosView.qml" line="89"/>
        <source>Video(s) deleted from playlist</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../PlaylistVideosView.qml" line="110"/>
        <source>No videos found</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../PlaylistVideosView.qml" line="168"/>
        <source>Videos</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../PlaylistVideosView.qml" line="182"/>
        <source>Updated</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../PlaylistVideosView.qml" line="205"/>
        <source>Play all</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../PlaylistVideosView.qml" line="213"/>
        <source>Loading playlist videos. Please wait</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>PlaylistsView</name>
    <message>
        <location filename="../PlaylistsView.qml" line="50"/>
        <source>New playlist created</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../PlaylistsView.qml" line="54"/>
        <source>Playlist deleted</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../PlaylistsView.qml" line="87"/>
        <source>No playlists found</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>ProxyDialog</name>
    <message>
        <location filename="../ProxyDialog.qml" line="35"/>
        <source>Network Proxy</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../ProxyDialog.qml" line="49"/>
        <source>Host (e.g. 192.168.100.1)</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../ProxyDialog.qml" line="56"/>
        <source>Port (e.g. 8080)</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>SearchBar</name>
    <message>
        <location filename="../SearchBar.qml" line="185"/>
        <source>Order by:</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../SettingsDialog.qml" line="217"/>
        <source>Your saved searches have been cleared</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="220"/>
        <source>Database error. Unable to clear searches</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="279"/>
        <source>Settings</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="345"/>
        <source>Playback quality</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="354"/>
        <source>Download quality</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="320"/>
        <source>Start downloads</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="441"/>
        <source>Appearance</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="466"/>
        <source>System</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="474"/>
        <source>Download location</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="483"/>
        <source>Screen orientation</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="336"/>
        <source>Media player</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="193"/>
        <location filename="../SettingsDialog.qml" line="458"/>
        <location filename="../SettingsDialog.qml" line="460"/>
        <source>Language</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="40"/>
        <location filename="../SettingsDialog.qml" line="41"/>
        <source>High quality</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="47"/>
        <source>Russian</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="48"/>
        <source>Most recent</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="48"/>
        <source>Most viewed</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="49"/>
        <source>Archive</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="49"/>
        <source>Latest subscription videos</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="50"/>
        <source>My uploads</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="50"/>
        <source>My favourites</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="136"/>
        <location filename="../SettingsDialog.qml" line="196"/>
        <source>Network Proxy</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="160"/>
        <location filename="../SettingsDialog.qml" line="347"/>
        <source>Playback Quality</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="163"/>
        <location filename="../SettingsDialog.qml" line="356"/>
        <source>Download Quality</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="166"/>
        <location filename="../SettingsDialog.qml" line="322"/>
        <source>Start Downloads</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="184"/>
        <location filename="../SettingsDialog.qml" line="485"/>
        <source>Screen Orientation</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="187"/>
        <location filename="../SettingsDialog.qml" line="338"/>
        <source>Media Player</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="40"/>
        <location filename="../SettingsDialog.qml" line="41"/>
        <source>Mobile</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="41"/>
        <source>360p</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="41"/>
        <source>480p</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="41"/>
        <source>720p</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="42"/>
        <source>Automatically</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="42"/>
        <source>Manually</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="43"/>
        <source>On</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="43"/>
        <source>Off</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="44"/>
        <source>Automatic</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="44"/>
        <source>Landscape</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="44"/>
        <source>Portrait</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="45"/>
        <source>Light</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="45"/>
        <source>Dark</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="45"/>
        <source>Midnight</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="46"/>
        <source>English</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="46"/>
        <source>German</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="46"/>
        <source>Finnish</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="46"/>
        <source>Italian</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="46"/>
        <source>Dutch</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="47"/>
        <source>Polish</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="47"/>
        <source>Portuguese</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="121"/>
        <source>Your settings have been saved</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="126"/>
        <location filename="../SettingsDialog.qml" line="169"/>
        <source>Download Path</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="128"/>
        <source>Download Location</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="172"/>
        <location filename="../SettingsDialog.qml" line="372"/>
        <source>Category Feed One</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="175"/>
        <location filename="../SettingsDialog.qml" line="381"/>
        <source>Category Feed Two</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="178"/>
        <location filename="../SettingsDialog.qml" line="390"/>
        <source>Order Category Videos By</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="181"/>
        <location filename="../SettingsDialog.qml" line="406"/>
        <source>Safe Search</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="190"/>
        <location filename="../SettingsDialog.qml" line="449"/>
        <location filename="../SettingsDialog.qml" line="451"/>
        <source>Theme</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="199"/>
        <location filename="../SettingsDialog.qml" line="509"/>
        <source>Widget Feed One</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="202"/>
        <location filename="../SettingsDialog.qml" line="518"/>
        <source>Widget Feed Two</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="205"/>
        <location filename="../SettingsDialog.qml" line="527"/>
        <source>Widget Feed Three</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="208"/>
        <location filename="../SettingsDialog.qml" line="536"/>
        <source>Widget Feed Four</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="229"/>
        <source>Your facebook token has been deleted</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="232"/>
        <source>Database error. Unable to delete facebook token</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="303"/>
        <source>Network</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="311"/>
        <source>Network proxy</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="328"/>
        <source>Media</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="362"/>
        <source>YouTube categories</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="370"/>
        <source>Category feed one</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="379"/>
        <source>Category feed two</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="388"/>
        <source>Order category videos by</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="396"/>
        <source>YouTube searches</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="404"/>
        <source>Safe search</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="422"/>
        <source>Social networks</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="433"/>
        <source>Delete facebook token</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="499"/>
        <source>Widget</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="507"/>
        <source>Feed one</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="516"/>
        <source>Feed two</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="525"/>
        <source>Feed three</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="534"/>
        <source>Feed four</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="312"/>
        <source>None</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="415"/>
        <source>Clear saved searches</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>Sharing</name>
    <message>
        <location filename="../../../sharing.cpp" line="78"/>
        <source>Error - Server repsonse is: </source>
        <translation></translation>
    </message>
</context>
<context>
    <name>SubscriptionsView</name>
    <message>
        <location filename="../SubscriptionsView.qml" line="34"/>
        <source>Latest Subscriptions Videos</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../SubscriptionsView.qml" line="41"/>
        <source>You have unsubscribed to this channel</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../SubscriptionsView.qml" line="85"/>
        <source>No subscriptions found</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>UploadDialog</name>
    <message>
        <location filename="../UploadDialog.qml" line="70"/>
        <source>Cars &amp; Vehicles</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../UploadDialog.qml" line="70"/>
        <source>Comedy</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../UploadDialog.qml" line="71"/>
        <source>Education</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../UploadDialog.qml" line="13"/>
        <location filename="../UploadDialog.qml" line="71"/>
        <source>Entertainment</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../UploadDialog.qml" line="72"/>
        <source>Gaming</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../UploadDialog.qml" line="72"/>
        <source>Film &amp; Animation</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../UploadDialog.qml" line="73"/>
        <source>Howto &amp; Style</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../UploadDialog.qml" line="73"/>
        <source>Music</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../UploadDialog.qml" line="73"/>
        <source>News &amp; Politics</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../UploadDialog.qml" line="74"/>
        <source>Non-profits &amp; Activism</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../UploadDialog.qml" line="74"/>
        <source>People &amp; Blogs</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../UploadDialog.qml" line="75"/>
        <source>Pets &amp; Animals</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../UploadDialog.qml" line="75"/>
        <source>Science &amp; Technology</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../UploadDialog.qml" line="76"/>
        <source>Sport</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../UploadDialog.qml" line="76"/>
        <source>Travel &amp; Events</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../UploadDialog.qml" line="29"/>
        <location filename="../UploadDialog.qml" line="220"/>
        <source>Category</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../UploadDialog.qml" line="118"/>
        <source>Upload Video</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../UploadDialog.qml" line="143"/>
        <source>File</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../UploadDialog.qml" line="152"/>
        <location filename="../UploadDialog.qml" line="228"/>
        <source>None chosen</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../UploadDialog.qml" line="168"/>
        <source>Title</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../UploadDialog.qml" line="181"/>
        <source>Description (optional)</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../UploadDialog.qml" line="193"/>
        <source>Tags (seperated by commas)</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../UploadDialog.qml" line="206"/>
        <source>Private?</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>UploadProgressDialog</name>
    <message>
        <location filename="../UploadProgressDialog.qml" line="6"/>
        <source>Starting upload</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../UploadProgressDialog.qml" line="30"/>
        <source>Upload Progress</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../UploadProgressDialog.qml" line="42"/>
        <source>Filename</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../UploadProgressDialog.qml" line="57"/>
        <source>Title</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../UploadProgressDialog.qml" line="91"/>
        <source>Abort</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../UploadProgressDialog.qml" line="91"/>
        <source>Close</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../UploadProgressDialog.qml" line="91"/>
        <location filename="../UploadProgressDialog.qml" line="97"/>
        <location filename="../UploadProgressDialog.qml" line="115"/>
        <source>Upload is in progress</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>UserInfoDialog</name>
    <message>
        <location filename="../UserInfoDialog.qml" line="106"/>
        <source>Profile</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../UserInfoDialog.qml" line="152"/>
        <source>Uploads</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../UserInfoDialog.qml" line="158"/>
        <source>Subscribers</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../UserInfoDialog.qml" line="178"/>
        <source>Name</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../UserInfoDialog.qml" line="184"/>
        <source>Age</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../UserInfoDialog.qml" line="197"/>
        <location filename="../UserInfoDialog.qml" line="215"/>
        <location filename="../UserInfoDialog.qml" line="221"/>
        <source>None</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../UserInfoDialog.qml" line="203"/>
        <source>Gender</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../UserInfoDialog.qml" line="209"/>
        <source>Location</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../UserInfoDialog.qml" line="215"/>
        <source>Male</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../UserInfoDialog.qml" line="215"/>
        <source>Female</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../UserInfoDialog.qml" line="236"/>
        <source>About</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../UserInfoDialog.qml" line="254"/>
        <source>No info</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../UserInfoDialog.qml" line="269"/>
        <source>Unsubscribe</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../UserInfoDialog.qml" line="269"/>
        <source>Subscribe</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UserVideosView</name>
    <message>
        <location filename="../UserVideosView.qml" line="127"/>
        <source>You have subscribed to &apos;</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../UserVideosView.qml" line="131"/>
        <source>You have unsubscribed to &apos;</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../UserVideosView.qml" line="151"/>
        <source>No videos found</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../UserVideosView.qml" line="209"/>
        <source>Subscribers</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../UserVideosView.qml" line="223"/>
        <source>Videos</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../UserVideosView.qml" line="246"/>
        <source>Unsubscribe</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../UserVideosView.qml" line="246"/>
        <source>Subscribe</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>VideoInfoView</name>
    <message>
        <location filename="../VideoInfoView.qml" line="15"/>
        <source>No description</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../VideoInfoView.qml" line="240"/>
        <source>Info</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../VideoInfoView.qml" line="278"/>
        <source>Comments</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../VideoInfoView.qml" line="316"/>
        <source>Related</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../VideoInfoView.qml" line="401"/>
        <location filename="../VideoInfoView.qml" line="404"/>
        <source>By </source>
        <translation></translation>
    </message>
    <message>
        <location filename="../VideoInfoView.qml" line="403"/>
        <location filename="../VideoInfoView.qml" line="406"/>
        <source> on </source>
        <translation></translation>
    </message>
    <message>
        <location filename="../VideoInfoView.qml" line="474"/>
        <source>Views</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../VideoInfoView.qml" line="488"/>
        <source>Description</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../VideoInfoView.qml" line="504"/>
        <source>Tags</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../VideoInfoView.qml" line="514"/>
        <source>No tags</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../VideoInfoView.qml" line="583"/>
        <source>No comments</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../VideoInfoView.qml" line="583"/>
        <source> comments</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../VideoInfoView.qml" line="697"/>
        <source>No related videos</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>VideoListDelegate</name>
    <message>
        <location filename="../VideoListDelegate.qml" line="51"/>
        <source>By </source>
        <translation></translation>
    </message>
    <message>
        <location filename="../VideoListDelegate.qml" line="51"/>
        <source> on </source>
        <translation></translation>
    </message>
    <message>
        <location filename="../VideoListDelegate.qml" line="101"/>
        <source>Views</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>VideoListView</name>
    <message>
        <location filename="../VideoListView.qml" line="79"/>
        <source>Video(s) deleted from favourites</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../VideoListView.qml" line="101"/>
        <source>No videos found</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>VideoPlaybackView</name>
    <message>
        <location filename="../VideoPlaybackView.qml" line="233"/>
        <location filename="../VideoPlaybackView.qml" line="422"/>
        <location filename="../VideoPlaybackView.qml" line="1024"/>
        <source>Loading...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../VideoPlaybackView.qml" line="731"/>
        <source>Info</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../VideoPlaybackView.qml" line="769"/>
        <source>Comments</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../VideoPlaybackView.qml" line="807"/>
        <source>Playlist</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../VideoPlaybackView.qml" line="889"/>
        <source>By </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../VideoPlaybackView.qml" line="889"/>
        <source> on </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../VideoPlaybackView.qml" line="889"/>
        <source>Added on </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../VideoPlaybackView.qml" line="954"/>
        <source>Views</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../VideoPlaybackView.qml" line="968"/>
        <source>Description</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../VideoPlaybackView.qml" line="976"/>
        <source>No description</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../VideoPlaybackView.qml" line="1001"/>
        <source>No comments</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../VideoPlaybackView.qml" line="1001"/>
        <source> comments</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>YouTube</name>
    <message>
        <location filename="../../../youtube.cpp" line="43"/>
        <source>Error obtaining access token</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../../youtube.cpp" line="54"/>
        <source>Authentication failed</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../../youtube.cpp" line="58"/>
        <source>You are signed in to YouTube as &apos;</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../../youtube.cpp" line="120"/>
        <location filename="../../../youtube.cpp" line="229"/>
        <source>Error - Server repsonse is: </source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../../youtube.cpp" line="170"/>
        <location filename="../../../youtube.cpp" line="178"/>
        <source>Upload aborted</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../../youtube.cpp" line="185"/>
        <source>Upload interrupted. Attempting to resume...</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../../youtube.cpp" line="189"/>
        <source>Upload failed</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../../youtube.cpp" line="195"/>
        <source>Upload is completed</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../../youtube.cpp" line="400"/>
        <source>Error: Unable to retrieve video</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>main</name>
    <message>
        <location filename="../main.qml" line="462"/>
        <source>Video(s) already in download queue</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../main.qml" line="463"/>
        <source>Audio track(s) added to download queue</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../main.qml" line="464"/>
        <source>Audio track(s) already in download queue</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../main.qml" line="456"/>
        <source>Video(s) added to favourites</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../main.qml" line="458"/>
        <source>Video(s) added to playlist</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../main.qml" line="459"/>
        <source>New playlist created</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../main.qml" line="270"/>
        <source>Conversion of &apos;</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../main.qml" line="270"/>
        <source>&apos; failed</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../main.qml" line="285"/>
        <source>Queued</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../main.qml" line="285"/>
        <source>Paused</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../main.qml" line="285"/>
        <source>Downloading</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../main.qml" line="285"/>
        <source>Failed</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../main.qml" line="285"/>
        <source>Converting</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../main.qml" line="41"/>
        <source>Most Recent</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../main.qml" line="453"/>
        <source>Your rating has been added</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main.qml" line="454"/>
        <source>You cannot rate your own videos</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main.qml" line="455"/>
        <source>Your comment has been added</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main.qml" line="457"/>
        <source>Video already in favourites</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main.qml" line="460"/>
        <source>Video shared on facebook</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main.qml" line="461"/>
        <source>Videos(s) added to download queue</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main.qml" line="465"/>
        <source>You are not signed in to a YouTube account</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main.qml" line="466"/>
        <source>No YouTube account found</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main.qml" line="467"/>
        <source>Use the cuteTube Player to access this feature</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main.qml" line="34"/>
        <source>Cars &amp; Vehicles</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main.qml" line="34"/>
        <source>Comedy</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main.qml" line="35"/>
        <source>Education</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main.qml" line="35"/>
        <source>Entertainment</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main.qml" line="36"/>
        <source>Film &amp; Animation</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main.qml" line="36"/>
        <source>Gaming</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main.qml" line="37"/>
        <source>Howto &amp; Style</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main.qml" line="37"/>
        <source>Music</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main.qml" line="37"/>
        <source>News &amp; Politics</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main.qml" line="38"/>
        <source>Non-profits &amp; Activism</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main.qml" line="38"/>
        <source>People &amp; Blogs</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main.qml" line="39"/>
        <source>Pets &amp; Animals</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main.qml" line="39"/>
        <source>Science &amp; Technology</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main.qml" line="40"/>
        <source>Sport</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main.qml" line="40"/>
        <source>Travel &amp; Events</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main.qml" line="41"/>
        <source>Most Viewed</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../main.qml" line="42"/>
        <source>Relevance</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main.qml" line="42"/>
        <source>Date</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main.qml" line="42"/>
        <source>Views</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main.qml" line="42"/>
        <source>Rating</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main.qml" line="468"/>
        <source>Unable to play videos at 360p quality or higher</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
